@@ -17,7 +17,7 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
@@ -383,11 +383,12 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
+                always_use_jwt_access=True,
             )
 
     def get_question(
         self,
-        request: question_service.GetQuestionRequest = None,
+        request: Union[question_service.GetQuestionRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -397,7 +398,7 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
         r"""Gets a previously created question.
 
         Args:
-            request (google.cloud.dataqna_v1alpha.types.GetQuestionRequest):
+            request (Union[google.cloud.dataqna_v1alpha.types.GetQuestionRequest, dict]):
                 The request object. A request to get a previously
                 created question.
             name (str):
@@ -461,7 +462,7 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
 
     def create_question(
         self,
-        request: question_service.CreateQuestionRequest = None,
+        request: Union[question_service.CreateQuestionRequest, dict] = None,
         *,
         parent: str = None,
         question: gcd_question.Question = None,
@@ -472,7 +473,7 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
         r"""Creates a question.
 
         Args:
-            request (google.cloud.dataqna_v1alpha.types.CreateQuestionRequest):
+            request (Union[google.cloud.dataqna_v1alpha.types.CreateQuestionRequest, dict]):
                 The request object. Request to create a question
                 resource.
             parent (str):
@@ -544,7 +545,7 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
 
     def execute_question(
         self,
-        request: question_service.ExecuteQuestionRequest = None,
+        request: Union[question_service.ExecuteQuestionRequest, dict] = None,
         *,
         name: str = None,
         interpretation_index: int = None,
@@ -555,7 +556,7 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
         r"""Executes an interpretation.
 
         Args:
-            request (google.cloud.dataqna_v1alpha.types.ExecuteQuestionRequest):
+            request (Union[google.cloud.dataqna_v1alpha.types.ExecuteQuestionRequest, dict]):
                 The request object. Request to execute an
                 interpretation.
             name (str):
@@ -628,7 +629,7 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
 
     def get_user_feedback(
         self,
-        request: question_service.GetUserFeedbackRequest = None,
+        request: Union[question_service.GetUserFeedbackRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -638,7 +639,7 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
         r"""Gets previously created user feedback.
 
         Args:
-            request (google.cloud.dataqna_v1alpha.types.GetUserFeedbackRequest):
+            request (Union[google.cloud.dataqna_v1alpha.types.GetUserFeedbackRequest, dict]):
                 The request object. Request to get user feedback.
             name (str):
                 Required. The unique identifier for the user feedback.
@@ -698,7 +699,7 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
 
     def update_user_feedback(
         self,
-        request: question_service.UpdateUserFeedbackRequest = None,
+        request: Union[question_service.UpdateUserFeedbackRequest, dict] = None,
         *,
         user_feedback: gcd_user_feedback.UserFeedback = None,
         update_mask: field_mask_pb2.FieldMask = None,
@@ -710,7 +711,7 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
         there was none before (upsert).
 
         Args:
-            request (google.cloud.dataqna_v1alpha.types.UpdateUserFeedbackRequest):
+            request (Union[google.cloud.dataqna_v1alpha.types.UpdateUserFeedbackRequest, dict]):
                 The request object. Request to updates user feedback.
             user_feedback (google.cloud.dataqna_v1alpha.types.UserFeedback):
                 Required. The user feedback to
@@ -779,6 +780,19 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
         # Done; return the response.
         return response
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, traceback):
+        """Releases underlying transport's resources.
+
+        .. warning::
+            ONLY use as a context manager if the transport is NOT shared
+            with other clients! Exiting the with block will CLOSE the transport
+            and may cause errors in other clients!
+        """
+        self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
